@@ -1,16 +1,16 @@
 # coding=utf-8
 import copy
-
 from pprint import PrettyPrinter
 
 from ..base import BitbucketBase
 
 
 class BitbucketCloudBase(BitbucketBase):
-    def __init__(self, url, *args, **kwargs):
+    def __init__(self, url, link="self", *args, **kwargs):
         """
         Init the rest api wrapper
         :param url:       The base url used for the rest api.
+        :param link:      Attribute to resolve a url based on input data. If None, no tries to receive an url from input data
         :param *args:     The fixed arguments for the AtlassianRestApi.
         :param **kwargs:  The keyword arguments for the AtlassianRestApi.
 
@@ -23,8 +23,9 @@ class BitbucketCloudBase(BitbucketBase):
                 raise ValueError(
                     "Expected type of data is [{}], got [{}].".format(expected_type, self.get_data("type"))
                 )
-        if url is None:
-            url = self.get_link("self")
+        if url is None and link is not None:
+            url = self.get_link(link)
+
         super(BitbucketCloudBase, self).__init__(url, *args, **kwargs)
 
     def __str__(self):
