@@ -30,8 +30,8 @@ def request_mookup(*args, **kwargs):
 
     response_file = os.path.join(RESPONSE_ROOT, url, method)
     try:
-        with open(response_file) as f:
-            data = {"responses": {}, "__builtins__": {}, "true": True, "false": False}
+        with open(response_file, encoding="utf-8") as f:
+            data = {"responses": {}, "__builtins__": {}, "true": True, "false": False, "null": None}
             exec(f.read(), data)
             data = data["responses"][response_key]
             if type(data) is dict:
